==> haskell-filestore-0.6.5.1-47.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-filestore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filestore
version:              0.6.5.1
visibility:           public
id:                   filestore-0.6.5.1-IVSclw4dSfP2vbrao7ipWb
key:                  filestore-0.6.5.1-IVSclw4dSfP2vbrao7ipWb
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Gwern Branwen, Sebastiaan Visser
stability:            Experimental
synopsis:             Interface for versioning file stores.
description:
    The filestore library provides an abstract interface for a versioning
    file store, and modules that instantiate this interface.  Currently
    Git, Darcs, and Mercurial modules are provided, and other VCSs
    or databases could be added.

category:             Data
abi:                  061e829372dc41732740feab281f4a35
exposed:              True
exposed-modules:
    Data.FileStore Data.FileStore.Darcs Data.FileStore.Generic
    Data.FileStore.Git Data.FileStore.Mercurial Data.FileStore.Types
    Data.FileStore.Utils

hidden-modules:
    Data.FileStore.DarcsXml Data.FileStore.MercurialCommandServer
    Data.FileStore.Compat.Locale

import-dirs:          /usr/lib/ghc-9.6.6/site-local/filestore-0.6.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filestore-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filestore-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filestore
hs-libraries:         HSfilestore-0.6.5.1-IVSclw4dSfP2vbrao7ipWb
depends:
    Diff-0.5-yETzKh0qtuDUuvJdOns8X base-4.18.2.1 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC parsec-3.1.16.1
    process-1.6.19.0 split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 time-1.12.2
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt

haddock-interfaces:   /usr/share/doc/haskell-filestore/html/filestore.haddock
haddock-html:         /usr/share/doc/haskell-filestore/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filestore-0.6.5.1-48-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-filestore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filestore
version:              0.6.5.1
visibility:           public
id:                   filestore-0.6.5.1-4fGXGafM4vn3DfBp90lepj
key:                  filestore-0.6.5.1-4fGXGafM4vn3DfBp90lepj
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Gwern Branwen, Sebastiaan Visser
stability:            Experimental
synopsis:             Interface for versioning file stores.
description:
    The filestore library provides an abstract interface for a versioning
    file store, and modules that instantiate this interface.  Currently
    Git, Darcs, and Mercurial modules are provided, and other VCSs
    or databases could be added.

category:             Data
abi:                  6af24b0146d891068f94492f4762e329
exposed:              True
exposed-modules:
    Data.FileStore Data.FileStore.Darcs Data.FileStore.Generic
    Data.FileStore.Git Data.FileStore.Mercurial Data.FileStore.Types
    Data.FileStore.Utils

hidden-modules:
    Data.FileStore.DarcsXml Data.FileStore.MercurialCommandServer
    Data.FileStore.Compat.Locale

import-dirs:          /usr/lib/ghc-9.6.6/site-local/filestore-0.6.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filestore-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filestore-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filestore
hs-libraries:         HSfilestore-0.6.5.1-4fGXGafM4vn3DfBp90lepj
depends:
    Diff-0.5-8gj4s2z6jOl7FPRCGftIez base-4.18.2.1 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC parsec-3.1.16.1
    process-1.6.19.0 split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 time-1.12.2
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt

haddock-interfaces:   /usr/share/doc/haskell-filestore/html/filestore.haddock
haddock-html:         /usr/share/doc/haskell-filestore/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
